.. contents::

.. _connection:

**********
connection
**********
This module consists of an abstract parent class, ``Connection``, and three child classes, 
``Pipe``, ``Pump``, and ``Wire``.

.. autoclass:: pype_schema.connection.Connection
   :members:

.. autoclass:: pype_schema.connection.Pipe
   :members:

.. autoclass:: pype_schema.connection.Wire
  :members:
